@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2010 Index Data
+ * Copyright (C) 1995-2011 Index Data
  * See the file LICENSE for details.
  */
 
@@ -138,19 +138,20 @@ static void print_icu_converters(const struct config_t *p_config)
     if (p_config->xmloutput)
         fprintf(config.outfile, "<converters count=\"%d\" default=\"%s\">\n",
                 count, ucnv_getDefaultName());
-    else {    
+    else
+    {    
         fprintf(config.outfile, "Available ICU converters: %d\n", count);
         fprintf(config.outfile, "Default ICU Converter is: '%s'\n", 
                 ucnv_getDefaultName());
     }
     
-    for(i=0;i<count;i++)
+    for (i = 0; i < count; i++)
     {
         if (p_config->xmloutput)
             fprintf(config.outfile, "<converter id=\"%s\"/>\n", 
                     ucnv_getAvailableName(i));
         else     
-            fprintf(config.outfile, "%s ", ucnv_getAvailableName(i));
+            fprintf(config.outfile, "%s\n", ucnv_getAvailableName(i));
     }
     
     if (p_config->xmloutput)
@@ -177,13 +178,11 @@ static void print_icu_transliterators(const struct config_t *p_config)
         if (p_config->xmloutput)
             fprintf(config.outfile, "<transliterator id=\"%s\"/>\n", name);
         else
-            fprintf(config.outfile, " %s", name);
+            fprintf(config.outfile, "%s\n", name);
     }
     uenum_close(en);
     if (p_config->xmloutput)
-    {
         fprintf(config.outfile, "</transliterators>\n");
-    }
     else
     {
         fprintf(config.outfile, "\n\nUnicode Set Patterns:\n"
@@ -223,10 +222,8 @@ static void print_icu_transliterators(const struct config_t *p_config)
                 "   [A-Za-z]; Lower(); Latin-Katakana; Katakana-Hiragana (transforms latin and katagana to hiragana)\n"
                 "   [[:separator:][:start punctuation:][:initial punctuation:]] Remove \n"
                 "\n"
-                "see http://icu.sourceforge.net/userguide/Transform.html\n"
-                "    http://www.unicode.org/Public/UNIDATA/UCD.html\n"
-                "    http://icu.sourceforge.net/userguide/Transform.html\n"
-                "    http://icu.sourceforge.net/userguide/TransformRule.html\n"
+                "see http://userguide.icu-project.org/transforms/general\n"
+                "    http://www.unicode.org/reports/tr44/\n"
             );
         
         
@@ -283,8 +280,13 @@ static void print_icu_xml_locales(const struct config_t *p_config)
         fprintf(config.outfile, "<locales count=\"%d\" default=\"%s\" collations=\"%d\">\n", 
                 count, uloc_getDefault(), ucol_countAvailable());
     }
+    else
+    {
+        fprintf(config.outfile, "Available ICU locales: %d\n", count);
+        fprintf(config.outfile, "Default locale is: %s\n",  uloc_getDefault());
+    }
   
-    for(i=0;i<count;i++) 
+    for (i = 0; i < count; i++) 
     {
 
         keyword_len 
@@ -390,14 +392,14 @@ static void print_icu_xml_locales(const struct config_t *p_config)
             fprintf(config.outfile, "\n");
         }
         else
-            fprintf(config.outfile, "%s ", uloc_getAvailable(i));
+            fprintf(config.outfile, "%s\n", uloc_getAvailable(i));
     }
     if (p_config->xmloutput)
         fprintf(config.outfile, "</locales>\n");
     else
         fprintf(config.outfile, "\n");
 
-    if(U_FAILURE(status))
+    if (U_FAILURE(status))
     {
         fprintf(stderr, "ICU Error: %d %s\n", status, u_errorName(status));
         exit(2);
